Class: TrackRelay::Linter::Ga4Violation
- Inherits:
-
Struct
- Object
- Struct
- TrackRelay::Linter::Ga4Violation
- Defined in:
- lib/track_relay/linter.rb
Overview
One row in the GA4 lint report.
Instance Attribute Summary collapse
-
#count ⇒ Object
How many JSONL lines contained this event name (regardless of param signature — the GA4 lint groups purely by event name).
-
#event_name ⇒ Object
The event name as it appeared in the JSONL ‘event` field.
-
#reason ⇒ Object
Human-readable description of the GA4 rule that was violated.
Instance Attribute Details
#count ⇒ Object
How many JSONL lines contained this event name (regardless of param signature — the GA4 lint groups purely by event name).
136 |
# File 'lib/track_relay/linter.rb', line 136 Ga4Violation = Struct.new(:event_name, :reason, :count, keyword_init: true) |
#event_name ⇒ Object
The event name as it appeared in the JSONL ‘event` field.
136 |
# File 'lib/track_relay/linter.rb', line 136 Ga4Violation = Struct.new(:event_name, :reason, :count, keyword_init: true) |
#reason ⇒ Object
Human-readable description of the GA4 rule that was violated.
136 |
# File 'lib/track_relay/linter.rb', line 136 Ga4Violation = Struct.new(:event_name, :reason, :count, keyword_init: true) |