Exception: TrackRelay::ReservedKeyError

Inherits:
Error
  • Object
show all
Defined in:
lib/track_relay/errors.rb

Overview

Raised at catalog-load time when an event declares a param whose name collides with one of the reserved context keys (see RESERVED_KEYS).