Exception: TrackRelay::UnknownEventError

Inherits:
Error
  • Object
show all
Defined in:
lib/track_relay/errors.rb

Overview

Raised when callers attempt to track an event that is not present in the catalog and untyped events are disabled.